==> google-cloud-cpp-1.36.0.tar.gz: google-cloud-cpp-1.36.0/google/cloud/websecurityscanner/quickstart/quickstart.cc <==
// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "google/cloud/websecurityscanner/web_security_scanner_client.h"
#include "google/cloud/project.h"
#include <iostream>
#include <stdexcept>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace websecurityscanner = ::google::cloud::websecurityscanner;
  auto client = websecurityscanner::WebSecurityScannerClient(
      websecurityscanner::MakeWebSecurityScannerConnection());
  auto const project = google::cloud::Project(argv[1]);
  google::cloud::websecurityscanner::v1::ListScanConfigsRequest request;
  request.set_parent(project.FullName());
  for (auto c : client.ListScanConfigs(request)) {
    if (!c) throw std::runtime_error(c.status().message());
    std::cout << c->DebugString() << "\n";
  }

  return 0;
} catch (std::exception const& ex) {
  std::cerr << "Standard exception raised: " << ex.what() << "\n";
  return 1;
}

==> google-cloud-cpp-2.19.0.tar.gz: google-cloud-cpp-2.19.0/google/cloud/websecurityscanner/quickstart/quickstart.cc <==
// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! [all]
#include "google/cloud/websecurityscanner/v1/web_security_scanner_client.h"
#include "google/cloud/project.h"
#include <iostream>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace websecurityscanner = ::google::cloud::websecurityscanner_v1;
  auto client = websecurityscanner::WebSecurityScannerClient(
      websecurityscanner::MakeWebSecurityScannerConnection());
  auto const project = google::cloud::Project(argv[1]);
  google::cloud::websecurityscanner::v1::ListScanConfigsRequest request;
  request.set_parent(project.FullName());
  for (auto c : client.ListScanConfigs(request)) {
    if (!c) throw std::move(c).status();
    std::cout << c->DebugString() << "\n";
  }

  return 0;
} catch (google::cloud::Status const& status) {
  std::cerr << "google::cloud::Status thrown: " << status << "\n";
  return 1;
}
//! [all]
